<?php declare(strict_types = 1);
/*
** Zabbix
** Copyright (C) 2001-2023 Zabbix SIA
** Copyright (C) 2024 Cybertrust Japan Co., Ltd.
**
** This program is free software: you can redistribute it and/or modify it under the terms of
** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
**
** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
** See the GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License along with this program.
** If not, see <https://www.gnu.org/licenses/>.
**/


/**
 * Controller for snapshot update.
 */
class CControllerSnapshotUpdate extends CController {

	private $snapshot;

	protected function checkInput(): bool {
		$fields = [
			'snapshotid' =>		'required|db snapshots.snapshotid',
			'name'		=> 'required|db snapshots.name|not_empty',
			'description'		=> 'db snapshots.description'
		];

		$ret = $this->validateInput($fields);

		if (!$ret) {
			$this->setResponse(
				new CControllerResponseData(['main_block' => json_encode([
					'error' => [
						'title' => _('Cannot update snapshot'),
						'messages' => array_column(get_and_clear_messages(), 'message')
					]
				])])
			);
		}

		return $ret;
	}

	protected function checkPermissions(): bool {
		$snapshots = DBfetchArray(DBSelect(
			'select snapshotid,name,type,description from snapshots where snapshotid='.
			$this->getInput('snapshotid').
			';'
		));

		$this->snapshot = $snapshots[0];

		switch ($this->snapshot['type']) {
			case ZBX_SNAPSHOT_TYPE_HOST:
			case ZBX_SNAPSHOT_TYPE_TEMPLATE:
				return $this->checkSnapshotAccess();
			default:
				return false;
		}
	}

	protected function doAction(): void {
		$snapshot = [
			'snapshotid' => $this->snapshot['snapshotid'],
			'name' => $this->getInput('name', $this->snapshot['name']),
			'description' => $this->getInput('description', $this->snapshot['description'])
		];

		$result = DBexecute(
			'update snapshots set '.
				'name = '.zbx_dbstr($snapshot['name']).', '.
				'description = '.zbx_dbstr($snapshot['description']).' '.
				'where snapshotid = '.$snapshot['snapshotid'].
				';'
			);

		if ($result) {
			$success = ['title' => _('Snapshot updated')];

			if ($messages = get_and_clear_messages()) {
				$success['messages'] = array_column($messages, 'message');
			}

			$output['success'] = $success;
		}
		else {
			$output['error'] = [
				'title' => _('Cannot update snapshot'),
				'messages' => array_column(get_and_clear_messages(), 'message')
			];
		}

		$this->setResponse(new CControllerResponseData(['main_block' => json_encode($output)]));
	}
}
