<?php declare(strict_types = 1);
/*
** Zabbix
** Copyright (C) 2001-2023 Zabbix SIA
** Copyright (C) 2024 Cybertrust Japan Co., Ltd.
**
** This program is free software: you can redistribute it and/or modify it under the terms of
** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
**
** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
** See the GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License along with this program.
** If not, see <https://www.gnu.org/licenses/>.
**/


/**
 * @var CView $this
 */
?>

<script type="text/javascript">
	const view = {
		editSnapshot(e, snapshotid) {
			e.preventDefault();
			const snapshot_data = {snapshotid};

			this.openSnapshotPopup(snapshot_data);
		},

		openSnapshotPopup(snapshot_data) {
			const original_url = location.href;
			const overlay = PopUp('popup.snapshot.edit', snapshot_data, {
				dialogueid: 'snapshot_edit',
				dialogue_class: 'modal-popup-large'
			});

			overlay.$dialogue[0].addEventListener('dialogue.create', this.events.snapshotSuccess, {once: true});
			overlay.$dialogue[0].addEventListener('dialogue.restore', this.events.snapshotSuccess, {once: true});
			overlay.$dialogue[0].addEventListener('dialogue.update', this.events.snapshotSuccess, {once: true});
			overlay.$dialogue[0].addEventListener('dialogue.delete', this.events.snapshotSuccess, {once: true});
			overlay.$dialogue[0].addEventListener('dialogue.close', () => {
				history.replaceState({}, '', original_url);
			}, {once: true});
		},

		massDeleteSnapshots(button) {
			const confirm_text = button.getAttribute('confirm');
			if (!confirm(confirm_text)) {
				return;
			}

			button.classList.add('is-loading');

			const curl = new Curl('zabbix.php');
			curl.setArgument('action', 'snapshot.massdelete');
			curl.setArgument('<?= CCsrfTokenHelper::CSRF_TOKEN_NAME ?>',
				<?= json_encode(CCsrfTokenHelper::get('snapshot')) ?>
			);

			fetch(curl.getUrl(), {
				method: 'POST',
				headers: {'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'},
				body: urlEncodeData({type: <?= $data['type'] ?>, snapshotids: Object.keys(chkbxRange.getSelectedIds())})
			})
				.then((response) => response.json())
				.then((response) => {
					if ('error' in response) {
						postMessageError(response.error.title);
						postMessageDetails('error', response.error.messages);
					}
					else if('success' in response) {
						postMessageOk(response.success.title);

						if ('messages' in response.success) {
							postMessageDetails('success', response.success.messages);
						}
					}

					uncheckTableRows('snapshots', []);
					location.href = location.href;
				})
				.catch(() => {
					const title = <?= json_encode(_('Unexpected server error.')) ?>;
					const message_box = makeMessageBox('bad', [], title)[0];

					clearMessages();
					addMessage(message_box);
				})
				.finally(() => {
					button.classList.remove('is-loading');
				});
		},

		events: {
			snapshotSuccess(e) {
				const data = e.detail;

				if ('success' in data) {
					postMessageOk(data.success.title);

					if ('messages' in data.success) {
						postMessageDetails('success', data.success.messages);
					}
				}

				uncheckTableRows('snapshots');
				location.href = location.href;
			}
		}
	};
</script>
